package Task::BeLike::DOY;
our $AUTHORITY = 'cpan:DOY';
#ABSTRACT: modules I use
$Task::BeLike::DOY::VERSION = '0.15';

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Task::BeLike::DOY - modules I use

=head1 VERSION

version 0.15

=head1 TASK CONTENTS

=head2 Development tools

=head3 L<App::ForkProve>

=head3 L<Carp::Always::Color> 0.03

=head3 L<Carp::Reply>

=head3 L<Data::Dump>

=head3 L<Devel::Cover>

=head3 L<Devel::NYTProf> 3.00

=head3 L<Devel::STDERR::Indent>

=head3 L<Devel::Trace>

=head3 L<Dist::Zilla> 4.00

=head3 L<Dist::Zilla::PluginBundle::DOY> 0.09

=head3 L<ExtUtils::MakeMaker::Dist::Zilla::Develop>

=head3 L<lib::require::all>

=head3 L<Pod::Coverage::TrustPod>

=head3 L<Reply>

=head3 L<Test::Pod>

=head3 L<Test::Pod::Coverage>

=head2 Useful optional deps for things

=head3 L<B::Keywords>

=head3 L<Term::ReadLine::Gnu>

=head2 CPAN interaction

=head3 L<App::cpanminus> 1.5007

Version 1.5007 required because: for build.log prompting

=head3 L<App::PAUSE::Comaint>

=head3 L<Pod::Cpandoc>

=head2 Other dependencies

=head3 L<Path::Class>

=head3 L<Term::ReadKey>

=head3 L<Email::Address>

=head3 L<Config::INI>

=head3 L<LastFM::Export>

=head3 L<DBD::SQLite>

=head3 L<URL::Search>

=begin taskweaver_parsing_is_broken




=end taskweaver_parsing_is_broken

=head1 AUTHOR

Jesse Luehrs <doy@tozt.net>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by Jesse Luehrs.

This is free software, licensed under:

  The MIT (X11) License

=cut
